MethodChannelLatHdrTranscoderV2 class
An implementation of LatHdrTranscoderV2Platform that uses method channels.
- Inheritance
-
- Object
- LatHdrTranscoderV2Platform
- MethodChannelLatHdrTranscoderV2
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCache(
) → Future< bool?> -
override
-
isHdr(
String path) → Future< bool?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onProgress(
) → Stream< double> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
transcoding(
String path) → Future< String?> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited