LatHdrTranscoderV2Platform class abstract

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() Future<bool?>
isHdr(String path) Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProgress() Stream<double>
toString() String
A string representation of this object.
inherited
transcoding(String path) Future<String?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance LatHdrTranscoderV2Platform
getter/setter pair